@@ -28,15 +28,17 @@ from elasticsearch.exceptions import ConflictError, RequestError
 import json
 import importlib
 
-from app.geocodingBackend import GeneralGeocodingManager, GeneralReverseManager, DensityRadius, \
+sys.path.append(".")
+
+from .app.geocodingBackend import GeneralGeocodingManager, GeneralReverseManager, DensityRadius, \
     Convex, RunModel
 
 # models import
-from app.models import frontend_models, density_models, common_models, user_metrics_models as USM
-from app.logger import log_error
+from .app.models import frontend_models, density_models, common_models, user_metrics_models as USM
+from .app.logger import log_error
 
 # import cython files
-from app.CythonOperations import create_convex_array, check_dups, zip_coordinate, check_lat_long_length, \
+from .app.CythonOperations import create_convex_array, check_dups, zip_coordinate, check_lat_long_length, \
     check_address_length, zip_coordinates_elastic, create_convex_elastic, coordinate_conv_package
 
 
